pub struct SetDelegate {
pub owner: Pubkey,
pub open_orders_account: Pubkey,
pub delegate_account: Pubkey,
}Expand description
Generated client accounts for SetDelegate.
Fields
owner: Pubkeyopen_orders_account: Pubkeydelegate_account: PubkeyTrait Implementations
Sourceimpl BorshSerialize for SetDelegatewhere
Pubkey: BorshSerialize,
impl BorshSerialize for SetDelegatewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for SetDelegate
impl ToAccountMetas for SetDelegate
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for SetDelegate
impl RefUnwindSafe for SetDelegate
impl Send for SetDelegate
impl Sync for SetDelegate
impl Unpin for SetDelegate
impl UnsafeUnpin for SetDelegate
impl UnwindSafe for SetDelegate