pub struct StubOracleCreate {
pub payer: Pubkey,
pub owner: Pubkey,
pub oracle: Pubkey,
pub mint: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for StubOracleCreate.
Fields
payer: Pubkeyowner: Pubkeyoracle: Pubkeymint: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for StubOracleCreatewhere
Pubkey: BorshSerialize,
impl BorshSerialize for StubOracleCreatewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for StubOracleCreate
impl ToAccountMetas for StubOracleCreate
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for StubOracleCreate
impl RefUnwindSafe for StubOracleCreate
impl Send for StubOracleCreate
impl Sync for StubOracleCreate
impl Unpin for StubOracleCreate
impl UnsafeUnpin for StubOracleCreate
impl UnwindSafe for StubOracleCreate