pub struct EventHeap {
pub header: EventHeapHeader,
pub nodes: [EventNode; 600],
pub reserved: [u8; 64],
}Expand description
Account: EventHeap
Fields
header: EventHeapHeadernodes: [EventNode; 600]reserved: [u8; 64]Trait Implementations
Sourceimpl AccountDeserialize for EventHeap
impl AccountDeserialize for EventHeap
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for EventHeap
impl AccountSerialize for EventHeap
Sourceimpl BorshDeserialize for EventHeapwhere
EventHeapHeader: BorshDeserialize,
[EventNode; 600]: BorshDeserialize,
[u8; 64]: BorshDeserialize,
impl BorshDeserialize for EventHeapwhere
EventHeapHeader: BorshDeserialize,
[EventNode; 600]: BorshDeserialize,
[u8; 64]: BorshDeserialize,
Sourceimpl BorshSerialize for EventHeap
impl BorshSerialize for EventHeap
impl Copy for EventHeap
Sourceimpl Discriminator for EventHeap
impl Discriminator for EventHeap
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]