pub struct StubOracle {
pub owner: Pubkey,
pub mint: Pubkey,
pub price: f64,
pub last_update_ts: i64,
pub last_update_slot: u64,
pub deviation: f64,
pub reserved: [u8; 104],
}Expand description
Account: StubOracle
Fields
owner: Pubkeymint: Pubkeyprice: f64last_update_ts: i64last_update_slot: u64deviation: f64reserved: [u8; 104]Trait Implementations
Sourceimpl AccountDeserialize for StubOracle
impl AccountDeserialize for StubOracle
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for StubOracle
impl AccountSerialize for StubOracle
Sourceimpl BorshDeserialize for StubOraclewhere
Pubkey: BorshDeserialize,
f64: BorshDeserialize,
i64: BorshDeserialize,
u64: BorshDeserialize,
[u8; 104]: BorshDeserialize,
impl BorshDeserialize for StubOraclewhere
Pubkey: BorshDeserialize,
f64: BorshDeserialize,
i64: BorshDeserialize,
u64: BorshDeserialize,
[u8; 104]: BorshDeserialize,
Sourceimpl BorshSerialize for StubOraclewhere
Pubkey: BorshSerialize,
f64: BorshSerialize,
i64: BorshSerialize,
u64: BorshSerialize,
[u8; 104]: BorshSerialize,
impl BorshSerialize for StubOraclewhere
Pubkey: BorshSerialize,
f64: BorshSerialize,
i64: BorshSerialize,
u64: BorshSerialize,
[u8; 104]: BorshSerialize,
Sourceimpl Clone for StubOracle
impl Clone for StubOracle
Sourcefn clone(&self) -> StubOracle
fn clone(&self) -> StubOracle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for StubOracle
Sourceimpl Discriminator for StubOracle
impl Discriminator for StubOracle
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]